@@ -4,7 +4,7 @@ use strict;
 
 package Class::Scaffold;
 BEGIN {
-  $Class::Scaffold::VERSION = '1.100980';
+  $Class::Scaffold::VERSION = '1.101400';
 }
 # ABSTRACT: Large-scale OOP application support
 
@@ -20,7 +20,7 @@ Class::Scaffold - Large-scale OOP application support
 
 =head1 VERSION
 
-version 1.100980
+version 1.101400
 
 =head1 DESCRIPTION
 
@@ -45,6 +45,11 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
+The development version lives at
+L<http://github.com/hanekomu/Class-Scaffold/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
+
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
