@@ -4,7 +4,7 @@ use strict;
 
 package Class::Scaffold::Base;
 BEGIN {
-  $Class::Scaffold::Base::VERSION = '1.100980';
+  $Class::Scaffold::Base::VERSION = '1.101400';
 }
 
 # ABSTRACT: Base class for all classes of the class framework.
@@ -121,7 +121,7 @@ Class::Scaffold::Base - Base class for all classes of the class framework.
 
 =head1 VERSION
 
-version 1.100980
+version 1.101400
 
 =head1 DESCRIPTION
 
@@ -194,6 +194,11 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
+The development version lives at
+L<http://github.com/hanekomu/Class-Scaffold/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
+
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
