@@ -4,7 +4,7 @@ use strict;
 
 package Class::Scaffold::Base_TEST;
 BEGIN {
-  $Class::Scaffold::Base_TEST::VERSION = '1.100980';
+  $Class::Scaffold::Base_TEST::VERSION = '1.101400';
 }
 # ABSTRACT: Test companion class for the general base class
 use Error::Hierarchy::Test 'throws2_ok';
@@ -44,7 +44,7 @@ Class::Scaffold::Base_TEST - Test companion class for the general base class
 
 =head1 VERSION
 
-version 1.100980
+version 1.101400
 
 =head1 METHODS
 
@@ -70,6 +70,11 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
+The development version lives at
+L<http://github.com/hanekomu/Class-Scaffold/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
+
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
