@@ -4,7 +4,7 @@ use strict;
 
 package Class::Scaffold::Context;
 BEGIN {
-  $Class::Scaffold::Context::VERSION = '1.100980';
+  $Class::Scaffold::Context::VERSION = '1.101400';
 }
 # ABSTRACT: Holds execution and job context
 use parent 'Class::Scaffold::Base';
@@ -44,7 +44,7 @@ Class::Scaffold::Context - Holds execution and job context
 
 =head1 VERSION
 
-version 1.100980
+version 1.101400
 
 =head1 METHODS
 
@@ -76,6 +76,11 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
+The development version lives at
+L<http://github.com/hanekomu/Class-Scaffold/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
+
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
