@@ -4,7 +4,7 @@ use strict;
 
 package Class::Scaffold::Delegate::Mixin;
 BEGIN {
-  $Class::Scaffold::Delegate::Mixin::VERSION = '1.100980';
+  $Class::Scaffold::Delegate::Mixin::VERSION = '1.101400';
 }
 # ABSTRACT: Mixin that provides access to the framework environment
 
@@ -28,7 +28,7 @@ Class::Scaffold::Delegate::Mixin - Mixin that provides access to the framework e
 
 =head1 VERSION
 
-version 1.100980
+version 1.101400
 
 =head1 METHODS
 
@@ -54,6 +54,11 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
+The development version lives at
+L<http://github.com/hanekomu/Class-Scaffold/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
+
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
