@@ -4,7 +4,7 @@ use strict;
 
 package Class::Scaffold::Environment_TEST;
 BEGIN {
-  $Class::Scaffold::Environment_TEST::VERSION = '1.100980';
+  $Class::Scaffold::Environment_TEST::VERSION = '1.101400';
 }
 # ABSTRACT: Companion test class for the framework environment base class
 use Error::Hierarchy::Test 'throws2_ok';
@@ -31,7 +31,7 @@ Class::Scaffold::Environment_TEST - Companion test class for the framework envir
 
 =head1 VERSION
 
-version 1.100980
+version 1.101400
 
 =head1 INSTALLATION
 
@@ -51,6 +51,11 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
+The development version lives at
+L<http://github.com/hanekomu/Class-Scaffold/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
+
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
