@@ -4,7 +4,7 @@ use strict;
 
 package Class::Scaffold::Exception;
 BEGIN {
-  $Class::Scaffold::Exception::VERSION = '1.100980';
+  $Class::Scaffold::Exception::VERSION = '1.101400';
 }
 # ABSTRACT: Base class for framework exceptions
 
@@ -28,7 +28,7 @@ Class::Scaffold::Exception - Base class for framework exceptions
 
 =head1 VERSION
 
-version 1.100980
+version 1.101400
 
 =head1 INSTALLATION
 
@@ -48,6 +48,11 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
+The development version lives at
+L<http://github.com/hanekomu/Class-Scaffold/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
+
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
