@@ -4,7 +4,7 @@ use strict;
 
 package Class::Scaffold::Exception::Loader;
 BEGIN {
-  $Class::Scaffold::Exception::Loader::VERSION = '1.100980';
+  $Class::Scaffold::Exception::Loader::VERSION = '1.101400';
 }
 # ABSTRACT: Exception raised when a class cannot be loaded
 use parent qw(Error::Hierarchy::Internal Class::Scaffold::Accessor);
@@ -23,7 +23,7 @@ Class::Scaffold::Exception::Loader - Exception raised when a class cannot be loa
 
 =head1 VERSION
 
-version 1.100980
+version 1.101400
 
 =head1 METHODS
 
@@ -49,6 +49,11 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
+The development version lives at
+L<http://github.com/hanekomu/Class-Scaffold/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
+
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
