@@ -4,7 +4,7 @@ use strict;
 
 package Class::Scaffold::Exception::NoSuchFactoryHandler;
 BEGIN {
-  $Class::Scaffold::Exception::NoSuchFactoryHandler::VERSION = '1.100980';
+  $Class::Scaffold::Exception::NoSuchFactoryHandler::VERSION = '1.101400';
 }
 # ABSTRACT: Exception raised on a factory look-up failure
 use parent 'Class::Scaffold::Exception';
@@ -35,7 +35,7 @@ Class::Scaffold::Exception::NoSuchFactoryHandler - Exception raised on a factory
 
 =head1 VERSION
 
-version 1.100980
+version 1.101400
 
 =head1 INSTALLATION
 
@@ -55,6 +55,11 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
+The development version lives at
+L<http://github.com/hanekomu/Class-Scaffold/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
+
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
