@@ -4,7 +4,7 @@ use strict;
 
 package Class::Scaffold::Factory::Type;
 BEGIN {
-  $Class::Scaffold::Factory::Type::VERSION = '1.100980';
+  $Class::Scaffold::Factory::Type::VERSION = '1.101400';
 }
 # ABSTRACT: Factory for framework object types
 use parent 'Class::Factory::Enhanced';
@@ -54,7 +54,7 @@ Class::Scaffold::Factory::Type - Factory for framework object types
 
 =head1 VERSION
 
-version 1.100980
+version 1.101400
 
 =head1 METHODS
 
@@ -88,6 +88,11 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
+The development version lives at
+L<http://github.com/hanekomu/Class-Scaffold/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
+
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
