@@ -4,7 +4,7 @@ use strict;
 
 package Class::Scaffold::HierarchicalDirty;
 BEGIN {
-  $Class::Scaffold::HierarchicalDirty::VERSION = '1.100980';
+  $Class::Scaffold::HierarchicalDirty::VERSION = '1.101400';
 }
 
 # ABSTRACT: Mixin that multiplexes the dirty flag among its subobjects
@@ -54,7 +54,7 @@ Class::Scaffold::HierarchicalDirty - Mixin that multiplexes the dirty flag among
 
 =head1 VERSION
 
-version 1.100980
+version 1.101400
 
 =head1 DESCRIPTION
 
@@ -93,6 +93,11 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
+The development version lives at
+L<http://github.com/hanekomu/Class-Scaffold/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
+
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
