@@ -4,7 +4,7 @@ use strict;
 
 package Class::Scaffold::Storable;
 BEGIN {
-  $Class::Scaffold::Storable::VERSION = '1.100980';
+  $Class::Scaffold::Storable::VERSION = '1.101400';
 }
 
 # ABSTRACT: Base class for all framework classes that support a storage.
@@ -116,7 +116,7 @@ Class::Scaffold::Storable - Base class for all framework classes that support a
 
 =head1 VERSION
 
-version 1.100980
+version 1.101400
 
 =head1 METHODS
 
@@ -146,6 +146,11 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
+The development version lives at
+L<http://github.com/hanekomu/Class-Scaffold/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
+
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
