@@ -4,7 +4,7 @@ use strict;
 
 package Class::Scaffold::Storable_TEST;
 BEGIN {
-  $Class::Scaffold::Storable_TEST::VERSION = '1.100980';
+  $Class::Scaffold::Storable_TEST::VERSION = '1.101400';
 }
 # ABSTRACT: Companion test class for the storable base class
 use Error::Hierarchy::Test 'throws2_ok';
@@ -26,7 +26,7 @@ sub run {
 
 package Class::Scaffold::Storable_TEST::x001;
 BEGIN {
-  $Class::Scaffold::Storable_TEST::x001::VERSION = '1.100980';
+  $Class::Scaffold::Storable_TEST::x001::VERSION = '1.101400';
 }
 use parent 'Class::Scaffold::Storable';
 1;
@@ -40,7 +40,7 @@ Class::Scaffold::Storable_TEST - Companion test class for the storable base clas
 
 =head1 VERSION
 
-version 1.100980
+version 1.101400
 
 =head1 INSTALLATION
 
@@ -60,6 +60,11 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
+The development version lives at
+L<http://github.com/hanekomu/Class-Scaffold/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
+
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
