@@ -4,7 +4,7 @@ use strict;
 
 package Class::Scaffold::Test;
 BEGIN {
-  $Class::Scaffold::Test::VERSION = '1.100980';
+  $Class::Scaffold::Test::VERSION = '1.101400';
 }
 # ABSTRACT: Base classes for framework test classes
 use Test::More;
@@ -56,7 +56,7 @@ Class::Scaffold::Test - Base classes for framework test classes
 
 =head1 VERSION
 
-version 1.100980
+version 1.101400
 
 =head1 METHODS
 
@@ -90,6 +90,11 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
+The development version lives at
+L<http://github.com/hanekomu/Class-Scaffold/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
+
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
