@@ -4,7 +4,7 @@ use strict;
 
 package Class::Scaffold::Test::UtilLoader;
 BEGIN {
-  $Class::Scaffold::Test::UtilLoader::VERSION = '1.100980';
+  $Class::Scaffold::Test::UtilLoader::VERSION = '1.101400';
 }
 # ABSTRACT: Load other classes necessary for tests
 use Class::Scaffold::YAML::Marshall::Constant;
@@ -27,7 +27,7 @@ Class::Scaffold::Test::UtilLoader - Load other classes necessary for tests
 
 =head1 VERSION
 
-version 1.100980
+version 1.101400
 
 =head1 DESCRIPTION
 
@@ -55,6 +55,11 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
+The development version lives at
+L<http://github.com/hanekomu/Class-Scaffold/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
+
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
