@@ -4,7 +4,7 @@ use strict;
 
 package Class::Scaffold::YAML::Active;
 BEGIN {
-  $Class::Scaffold::YAML::Active::VERSION = '1.100980';
+  $Class::Scaffold::YAML::Active::VERSION = '1.101400';
 }
 # ABSTRACT: Base class for YAML::Active plugins
 use parent 'Class::Scaffold::Storable';
@@ -19,7 +19,7 @@ Class::Scaffold::YAML::Active - Base class for YAML::Active plugins
 
 =head1 VERSION
 
-version 1.100980
+version 1.101400
 
 =head1 INSTALLATION
 
@@ -39,6 +39,11 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
+The development version lives at
+L<http://github.com/hanekomu/Class-Scaffold/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
+
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
