@@ -4,7 +4,7 @@ use strict;
 
 package Class::Scaffold::YAML::Active::Constant;
 BEGIN {
-  $Class::Scaffold::YAML::Active::Constant::VERSION = '1.100980';
+  $Class::Scaffold::YAML::Active::Constant::VERSION = '1.101400';
 }
 # ABSTRACT: Plugin to get framework environment constants
 use parent 'Class::Scaffold::YAML::Active';
@@ -29,7 +29,7 @@ Class::Scaffold::YAML::Active::Constant - Plugin to get framework environment co
 
 =head1 VERSION
 
-version 1.100980
+version 1.101400
 
 =head1 METHODS
 
@@ -55,6 +55,11 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
+The development version lives at
+L<http://github.com/hanekomu/Class-Scaffold/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
+
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
