@@ -4,7 +4,7 @@ use strict;
 
 package Class::Scaffold::YAML::Active::Environment;
 BEGIN {
-  $Class::Scaffold::YAML::Active::Environment::VERSION = '1.100980';
+  $Class::Scaffold::YAML::Active::Environment::VERSION = '1.101400';
 }
 # ABSTRACT: Plugin for setting environment values
 use Class::Scaffold::Environment;
@@ -33,7 +33,7 @@ Class::Scaffold::YAML::Active::Environment - Plugin for setting environment valu
 
 =head1 VERSION
 
-version 1.100980
+version 1.101400
 
 =head1 METHODS
 
@@ -59,6 +59,11 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
+The development version lives at
+L<http://github.com/hanekomu/Class-Scaffold/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
+
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
