@@ -4,7 +4,7 @@ use strict;
 
 package Class::Scaffold::YAML::Active::Exception;
 BEGIN {
-  $Class::Scaffold::YAML::Active::Exception::VERSION = '1.100980';
+  $Class::Scaffold::YAML::Active::Exception::VERSION = '1.101400';
 }
 # ABSTRACT: Plugin for recording an exception for a test
 use YAML::Active qw/assert_hashref hash_activate/;
@@ -31,7 +31,7 @@ Class::Scaffold::YAML::Active::Exception - Plugin for recording an exception for
 
 =head1 VERSION
 
-version 1.100980
+version 1.101400
 
 =head1 METHODS
 
@@ -57,6 +57,11 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
+The development version lives at
+L<http://github.com/hanekomu/Class-Scaffold/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
+
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
