@@ -4,7 +4,7 @@ use strict;
 
 package Class::Scaffold::YAML::Active::ExceptionContainer;
 BEGIN {
-  $Class::Scaffold::YAML::Active::ExceptionContainer::VERSION = '1.100980';
+  $Class::Scaffold::YAML::Active::ExceptionContainer::VERSION = '1.101400';
 }
 # ABSTRACT: Plugin that constructs an exception container
 use YAML::Active qw/assert_arrayref array_activate/;
@@ -43,7 +43,7 @@ Class::Scaffold::YAML::Active::ExceptionContainer - Plugin that constructs an ex
 
 =head1 VERSION
 
-version 1.100980
+version 1.101400
 
 =head1 METHODS
 
@@ -69,6 +69,11 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
+The development version lives at
+L<http://github.com/hanekomu/Class-Scaffold/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
+
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
