@@ -4,7 +4,7 @@ use strict;
 
 package Class::Scaffold::YAML::Marshall;
 BEGIN {
-  $Class::Scaffold::YAML::Marshall::VERSION = '1.100980';
+  $Class::Scaffold::YAML::Marshall::VERSION = '1.101400';
 }
 # ABSTRACT: Base class for marshalling plugins to YAML
 
@@ -21,7 +21,7 @@ Class::Scaffold::YAML::Marshall - Base class for marshalling plugins to YAML
 
 =head1 VERSION
 
-version 1.100980
+version 1.101400
 
 =head1 INSTALLATION
 
@@ -41,6 +41,11 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
+The development version lives at
+L<http://github.com/hanekomu/Class-Scaffold/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
+
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
