@@ -4,7 +4,7 @@ use strict;
 
 package Class::Scaffold::YAML::Marshall::Concat;
 BEGIN {
-  $Class::Scaffold::YAML::Marshall::Concat::VERSION = '1.100980';
+  $Class::Scaffold::YAML::Marshall::Concat::VERSION = '1.101400';
 }
 # ABSTRACT: Marshalling plugin to join array elements to a string
 use YAML::Marshall 'concat';
@@ -27,7 +27,7 @@ Class::Scaffold::YAML::Marshall::Concat - Marshalling plugin to join array eleme
 
 =head1 VERSION
 
-version 1.100980
+version 1.101400
 
 =head1 METHODS
 
@@ -53,6 +53,11 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
+The development version lives at
+L<http://github.com/hanekomu/Class-Scaffold/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
+
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
