@@ -4,7 +4,7 @@ use strict;
 
 package Class::Scaffold::YAML::Marshall::ExceptionContainer;
 BEGIN {
-  $Class::Scaffold::YAML::Marshall::ExceptionContainer::VERSION = '1.100980';
+  $Class::Scaffold::YAML::Marshall::ExceptionContainer::VERSION = '1.101400';
 }
 # ABSTRACT: Marshalling plugin that constructs an exception container
 use YAML::Marshall 'exception/container';
@@ -44,7 +44,7 @@ Class::Scaffold::YAML::Marshall::ExceptionContainer - Marshalling plugin that co
 
 =head1 VERSION
 
-version 1.100980
+version 1.101400
 
 =head1 METHODS
 
@@ -70,6 +70,11 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
+The development version lives at
+L<http://github.com/hanekomu/Class-Scaffold/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
+
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
