@@ -4,7 +4,7 @@ use strict;
 
 package Class::Scaffold::YAML::Marshall::PID;
 BEGIN {
-  $Class::Scaffold::YAML::Marshall::PID::VERSION = '1.100980';
+  $Class::Scaffold::YAML::Marshall::PID::VERSION = '1.101400';
 }
 # ABSTRACT: Marshalling plugin to get the current process id
 use YAML::Marshall 'pid';
@@ -22,7 +22,7 @@ Class::Scaffold::YAML::Marshall::PID - Marshalling plugin to get the current pro
 
 =head1 VERSION
 
-version 1.100980
+version 1.101400
 
 =head1 METHODS
 
@@ -48,6 +48,11 @@ Archive Network (CPAN). Visit L<http://www.perl.com/CPAN/> to find a CPAN
 site near you, or see
 L<http://search.cpan.org/dist/Class-Scaffold/>.
 
+The development version lives at
+L<http://github.com/hanekomu/Class-Scaffold/>.
+Instead of sending patches, please fork this project using the standard git
+and github infrastructure.
+
 =head1 AUTHORS
 
   Marcel Gruenauer <marcel@cpan.org>
